==> igniteui-react-core-16.16.1.tgz: package/esm2015/lib/WebActivePaneEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActivePaneEventArgsDescription } from "./WebActivePaneEventArgsDescription";
/**
 * @hidden
 */
export let WebActivePaneEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActivePaneEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebActivePaneEventArgsDescriptionMetadata.a == null) {
                WebActivePaneEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActivePaneEventArgsDescriptionMetadata.c(WebActivePaneEventArgsDescriptionMetadata.a);
            }
            if (a.g(WebActivePaneEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.s(WebActivePaneEventArgsDescriptionMetadata.a);
            WebActivePaneEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ActivePaneEventArgs");
            a.item("Detail", "ExportedType:WebActivePaneEventArgs");
        }
        static d(a) {
            WebActivePaneEventArgsDescriptionMetadata.b(a);
            a.u("WebActivePaneEventArgs", () => new WebActivePaneEventArgsDescription());
            a.t("WebActivePaneEventArgs", WebActivePaneEventArgsDescriptionMetadata.a);
        }
    }
    WebActivePaneEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebActivePaneEventArgsDescriptionMetadata, 'WebActivePaneEventArgsDescriptionMetadata');
    WebActivePaneEventArgsDescriptionMetadata.a = null;
    return WebActivePaneEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.0.0.tgz: package/esm2015/lib/WebActivePaneEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebActivePaneEventArgsDescription } from "./WebActivePaneEventArgsDescription";
/**
 * @hidden
 */
export let WebActivePaneEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActivePaneEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebActivePaneEventArgsDescriptionMetadata.a == null) {
                WebActivePaneEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActivePaneEventArgsDescriptionMetadata.c(WebActivePaneEventArgsDescriptionMetadata.a);
            }
            if (a.g(WebActivePaneEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.s(WebActivePaneEventArgsDescriptionMetadata.a);
            WebContentPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ActivePaneEventArgs");
            a.item("NewPane", "ExportedType:WebContentPane");
            a.item("OldPane", "ExportedType:WebContentPane");
        }
        static d(a) {
            WebActivePaneEventArgsDescriptionMetadata.b(a);
            a.u("WebActivePaneEventArgs", () => new WebActivePaneEventArgsDescription());
            a.t("WebActivePaneEventArgs", WebActivePaneEventArgsDescriptionMetadata.a);
        }
    }
    WebActivePaneEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebActivePaneEventArgsDescriptionMetadata, 'WebActivePaneEventArgsDescriptionMetadata');
    WebActivePaneEventArgsDescriptionMetadata.a = null;
    return WebActivePaneEventArgsDescriptionMetadata;
})();
